==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-cpuload/translations/cpuload_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>Charge CPU %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Paramétrage de &apos;Charge du processeur&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Afficher le texte</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalle de mise à jour :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientation de la barre :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Largeur de la barre :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>De bas en haut</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>De haut en bas</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>De gauche à droite</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>De droite à gauche</translation>
    </message>
</context>
</TS>

==> lxqt-panel-1.0.0.tar.xz: lxqt-panel-1.0.0/plugin-cpuload/translations/cpuload_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>Charge du CPU %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Paramétrage de &apos;Charge du processeur&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Afficher le texte</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Intervalle de mise à jour :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Orientation de la barre :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Largeur de la barre :</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>De bas en haut</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>De haut en bas</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>De gauche à droite</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>De droite à gauche</translation>
    </message>
</context>
</TS>
